package com.huashe.park.application.web.controller.cons;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.huashe.common.domain.AjaxResult;
import com.huashe.park.core.service.IConsPileHoleInfoService;
import com.huashe.park.core.service.IMachineProcessService;
import com.huashe.park.core.service.IPileMachineInfoService;
import com.huashe.park.domain.dto.cons.PileRealtimeIndex;
import com.huashe.park.domain.entity.ConsPileHoleInfo;
import com.huashe.park.domain.entity.MachineProcess;
import com.huashe.park.domain.entity.PileMachineInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 施工桩点信息Controller
 * 
 * @author ruoyi
 * @date 2025-02-13
 */
@RestController
@RequestMapping("/cons/pileHoleInfo")
public class ConsPileHoleInfoController extends BaseController {
    @Autowired
    private IConsPileHoleInfoService consPileHoleInfoService;

    @Autowired
    private IMachineProcessService machineProcessService;

    @Autowired
    private IPileMachineInfoService machineInfoService;

    /**
     * 查询施工桩点信息列表
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(ConsPileHoleInfo consPileHoleInfo) {
        startPage();
        List<ConsPileHoleInfo> list = consPileHoleInfoService.selectConsPileHoleInfoList(consPileHoleInfo);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:list')")
    @GetMapping("/list/realtime/index")
    public AjaxResult listIndex(ConsPileHoleInfo consPileHoleInfo) {
        List<PileRealtimeIndex> pileRealtimeIndices = consPileHoleInfoService
            .selectConsPileHoleRealtimeIndex(consPileHoleInfo);
        return AjaxResult.success(pileRealtimeIndices);
    }

    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:list')")
    @GetMapping("/list/realtime/index/{pileHoleId}")
    public AjaxResult pileHoleIndex(@PathVariable("pileHoleId") Long pileHoleId) {
        List<PileRealtimeIndex> pileRealtimeIndices = consPileHoleInfoService
            .selectConsPileHoleRealtimeIndex(new ConsPileHoleInfo() {
                {
                    setId(pileHoleId);
                }
            });
        if (ObjectUtils.isEmpty(pileRealtimeIndices)) {
            return AjaxResult.success();
        }
        PileRealtimeIndex pileRealtimeIndex = pileRealtimeIndices.get(0);
        PileMachineInfo pileMachineInfo = machineInfoService
            .selectPileMachineInfoById(pileRealtimeIndex.getMachineId());
        pileRealtimeIndex.setPileMachineInfo(pileMachineInfo);

        return AjaxResult.success(pileRealtimeIndex);
    }

    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:list')")
    @GetMapping("/list/his/index")
    public AjaxResult listHisIndex(ConsPileHoleInfo consPileHoleInfo) {
        ConsPileHoleInfo consPileHoleInfoDb = consPileHoleInfoService
            .selectConsPileHoleInfoById(consPileHoleInfo.getId());
        List<MachineProcess> machineProcesses = new ArrayList<>();
        if (ObjectUtils.isNotEmpty(consPileHoleInfo)) {
            machineProcesses = machineProcessService.selectMachineProcessList(new MachineProcess() {
                {
                    setPileId(consPileHoleInfoDb.getByteId());
                }
            });
        }
        return AjaxResult.success(machineProcesses);
    }

    /**
     * 导出施工桩点信息列表
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:export')")
    @Log(title = "施工桩点信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ConsPileHoleInfo consPileHoleInfo) {
        List<ConsPileHoleInfo> list = consPileHoleInfoService.selectConsPileHoleInfoList(consPileHoleInfo);
        ExcelUtil<ConsPileHoleInfo> util = new ExcelUtil<ConsPileHoleInfo>(ConsPileHoleInfo.class);
        util.exportExcel(response, list, "施工桩点信息数据");
    }

    /**
     * 获取施工桩点信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(consPileHoleInfoService.selectConsPileHoleInfoById(id));
    }

    /**
     * 新增施工桩点信息
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:add')")
    @Log(title = "施工桩点信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ConsPileHoleInfo consPileHoleInfo) {
        return toAjax(consPileHoleInfoService.insertConsPileHoleInfo(consPileHoleInfo));
    }

    /**
     * 修改施工桩点信息
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:edit')")
    @Log(title = "施工桩点信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ConsPileHoleInfo consPileHoleInfo) {
        return toAjax(consPileHoleInfoService.updateConsPileHoleInfo(consPileHoleInfo));
    }

    /**
     * 删除施工桩点信息
     */
    @PreAuthorize("@ss.hasPermi('cons:pileHoleInfo:remove')")
    @Log(title = "施工桩点信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(consPileHoleInfoService.deleteConsPileHoleInfoByIds(ids));
    }
}
